@@ -8,8 +8,12 @@ Submodules
 
     cut
     grid
+    torfile
+    torparser
+    analysis
+    plot
 """
 
-__version__ = '0.2.0'
+__version__ = '0.4.0'
 
-__all__ = ['cut', 'grid', 'torfile', 'torparser']
+__all__ = ['cut', 'grid', 'plot', 'torfile', 'torparser', 'analysis']
